@@ -9,4 +9,4 @@ def test_nothing():
     """
     Empty test
     """
-    pass  # pylint: disable=unnecessary-pass
+    pass
